@@ -15,29 +15,28 @@
  * @category   Zend
  * @package    Zend_Config
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: AllTests.php 8064 2008-02-16 10:58:39Z thomas $
+ * @version    $Id$
  */
 
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../TestHelper.php';
-
 if (!defined('PHPUnit_MAIN_METHOD')) {
     define('PHPUnit_MAIN_METHOD', 'Zend_Config_AllTests::main');
 }
 
+require_once 'Zend/Config/Writer/AllTests.php';
 require_once 'Zend/Config/IniTest.php';
+require_once 'Zend/Config/JsonTest.php';
 require_once 'Zend/Config/XmlTest.php';
+require_once 'Zend/Config/YamlTest.php';
 
 /**
  * @category   Zend
  * @package    Zend_Config
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Config
  */
 class Zend_Config_AllTests
 {
@@ -50,8 +49,12 @@ class Zend_Config_AllTests
     {
         $suite = new PHPUnit_Framework_TestSuite('Zend Framework - Zend_Config');
 
+        $suite->addTest(Zend_Config_Writer_AllTests::suite());
+
         $suite->addTestSuite('Zend_Config_IniTest');
+        $suite->addTestSuite('Zend_Config_JsonTest');
         $suite->addTestSuite('Zend_Config_XmlTest');
+        $suite->addTestSuite('Zend_Config_YamlTest');
 
         return $suite;
     }
