@@ -1,5 +1,4 @@
 <?php
-
 /**
  * Zend Framework
  *
@@ -16,32 +15,34 @@
  * @category   Zend
  * @package    Zend_Gdata
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2006 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @version    $Id $
  */
 
-/**
- * Test helper
- */
-require_once dirname(dirname(dirname(__FILE__))) . DIRECTORY_SEPARATOR . 'TestHelper.php';
-
 if (!defined('PHPUnit_MAIN_METHOD')) {
     define('PHPUnit_MAIN_METHOD', 'Zend_Gdata_AllTests::main');
 }
 
-require_once 'PHPUnit/Framework/TestSuite.php';
-require_once 'PHPUnit/TextUI/TestRunner.php';
-
 /**
  * Tests of the authentication URL generator
  */
 require_once 'Zend/Gdata/AuthSubTest.php';
 
+/**
+ * 
+ */
+require_once 'Zend/Gdata/Analytics/AccountFeedTest.php';
+require_once 'Zend/Gdata/Analytics/AccountQueryTest.php';
+require_once 'Zend/Gdata/Analytics/DataFeedTest.php';
+require_once 'Zend/Gdata/Analytics/DataQueryTest.php';
+
 /**
  * Tests that do not require online access to servers
  */
 require_once 'Zend/Gdata/AppTest.php';
 require_once 'Zend/Gdata/App/UtilTest.php';
+require_once 'Zend/Gdata/App/BaseTest.php';
 require_once 'Zend/Gdata/App/AuthorTest.php';
 require_once 'Zend/Gdata/App/CategoryTest.php';
 require_once 'Zend/Gdata/App/ContentTest.php';
@@ -56,6 +57,8 @@ require_once 'Zend/Gdata/QueryTest.php';
 require_once 'Zend/Gdata/AttendeeStatusTest.php';
 require_once 'Zend/Gdata/AttendeeTypeTest.php';
 require_once 'Zend/Gdata/CommentsTest.php';
+require_once 'Zend/Gdata/EntryTest.php';
+require_once 'Zend/Gdata/FeedTest.php';
 require_once 'Zend/Gdata/EntryLinkTest.php';
 require_once 'Zend/Gdata/EventStatusTest.php';
 require_once 'Zend/Gdata/ExtendedPropertyTest.php';
@@ -73,14 +76,6 @@ require_once 'Zend/Gdata/WhenTest.php';
 require_once 'Zend/Gdata/WhereTest.php';
 require_once 'Zend/Gdata/WhoTest.php';
 
-require_once 'Zend/Gdata/Gbase/ItemEntryTest.php';
-require_once 'Zend/Gdata/Gbase/ItemFeedTest.php';        
-require_once 'Zend/Gdata/Gbase/ItemQueryTest.php';
-require_once 'Zend/Gdata/Gbase/SnippetFeedTest.php';
-require_once 'Zend/Gdata/Gbase/SnippetQueryTest.php';        
-require_once 'Zend/Gdata/Gbase/QueryTest.php';
-require_once 'Zend/Gdata/Gbase/BaseAttributeTest.php';
-
 require_once 'Zend/Gdata/CalendarTest.php';
 require_once 'Zend/Gdata/CalendarFeedTest.php';
 require_once 'Zend/Gdata/CalendarEventTest.php';
@@ -138,12 +133,22 @@ require_once 'Zend/Gdata/Gapps/EmailListRecipientFeedTest.php';
 require_once 'Zend/Gdata/Gapps/EmailListRecipientQueryTest.php';
 require_once 'Zend/Gdata/Gapps/EmailListTest.php';
 require_once 'Zend/Gdata/Gapps/ErrorTest.php';
+require_once 'Zend/Gdata/Gapps/GroupEntryTest.php';
+require_once 'Zend/Gdata/Gapps/GroupFeedTest.php';
+require_once 'Zend/Gdata/Gapps/GroupQueryTest.php';
 require_once 'Zend/Gdata/Gapps/LoginTest.php';
+require_once 'Zend/Gdata/Gapps/MemberEntryTest.php';
+require_once 'Zend/Gdata/Gapps/MemberFeedTest.php';
+require_once 'Zend/Gdata/Gapps/MemberQueryTest.php';
 require_once 'Zend/Gdata/Gapps/NameTest.php';
 require_once 'Zend/Gdata/Gapps/NicknameEntryTest.php';
 require_once 'Zend/Gdata/Gapps/NicknameFeedTest.php';
 require_once 'Zend/Gdata/Gapps/NicknameQueryTest.php';
 require_once 'Zend/Gdata/Gapps/NicknameTest.php';
+require_once 'Zend/Gdata/Gapps/OwnerEntryTest.php';
+require_once 'Zend/Gdata/Gapps/OwnerFeedTest.php';
+require_once 'Zend/Gdata/Gapps/OwnerQueryTest.php';
+require_once 'Zend/Gdata/Gapps/PropertyTest.php';
 require_once 'Zend/Gdata/Gapps/QuotaTest.php';
 require_once 'Zend/Gdata/Gapps/ServiceExceptionTest.php';
 require_once 'Zend/Gdata/Gapps/UserEntryTest.php';
@@ -163,22 +168,37 @@ require_once 'Zend/Gdata/YouTube/CommentFeedTest.php';
 require_once 'Zend/Gdata/YouTube/CommentEntryTest.php';
 require_once 'Zend/Gdata/YouTube/ContactFeedTest.php';
 require_once 'Zend/Gdata/YouTube/ContactEntryTest.php';
+require_once 'Zend/Gdata/YouTube/VideoQueryTest.php';
+require_once 'Zend/Gdata/YouTube/ActivityFeedTest.php';
+require_once 'Zend/Gdata/YouTube/ActivityEntryTest.php';
 
+require_once 'Zend/Gdata/Books/CollectionFeedTest.php';
+require_once 'Zend/Gdata/Books/CollectionEntryTest.php';
+require_once 'Zend/Gdata/Books/VolumeFeedTest.php';
+require_once 'Zend/Gdata/Books/VolumeEntryTest.php';
 
 /**
  * Tests that do require online access to servers
  * and authentication credentials
  */
 require_once 'Zend/Gdata/GdataOnlineTest.php';
-require_once 'Zend/Gdata/GbaseOnlineTest.php';
 require_once 'Zend/Gdata/CalendarOnlineTest.php';
 require_once 'Zend/Gdata/SpreadsheetsOnlineTest.php';
 require_once 'Zend/Gdata/DocsOnlineTest.php';
 require_once 'Zend/Gdata/PhotosOnlineTest.php';
 require_once 'Zend/Gdata/GappsOnlineTest.php';
 require_once 'Zend/Gdata/YouTubeOnlineTest.php';
+require_once 'Zend/Gdata/BooksOnlineTest.php';
 require_once 'Zend/Gdata/SkipTests.php';
 
+/**
+ * @category   Zend
+ * @package    Zend_Gdata
+ * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Gdata
+ */
 class Zend_Gdata_AllTests
 {
 
@@ -201,6 +221,7 @@ class Zend_Gdata_AllTests
          */
         $suite->addTestSuite('Zend_Gdata_AppTest');
         $suite->addTestSuite('Zend_Gdata_App_UtilTest');
+        $suite->addTestSuite('Zend_Gdata_App_BaseTest');
         $suite->addTestSuite('Zend_Gdata_App_AuthorTest');
         $suite->addTestSuite('Zend_Gdata_App_CategoryTest');
         $suite->addTestSuite('Zend_Gdata_App_ContentTest');
@@ -211,10 +232,12 @@ class Zend_Gdata_AllTests
         $suite->addTestSuite('Zend_Gdata_App_CaptchaRequiredExceptionTest');
         $suite->addTestSuite('Zend_Gdata_GdataTest');
         $suite->addTestSuite('Zend_Gdata_QueryTest');
-        
+
         $suite->addTestSuite('Zend_Gdata_AttendeeStatusTest');
         $suite->addTestSuite('Zend_Gdata_AttendeeTypeTest');
         $suite->addTestSuite('Zend_Gdata_CommentsTest');
+        $suite->addTestSuite('Zend_Gdata_EntryTest');
+        $suite->addTestSuite('Zend_Gdata_FeedTest');
         $suite->addTestSuite('Zend_Gdata_EntryLinkTest');
         $suite->addTestSuite('Zend_Gdata_EventStatusTest');
         $suite->addTestSuite('Zend_Gdata_ExtendedPropertyTest');
@@ -232,20 +255,12 @@ class Zend_Gdata_AllTests
         $suite->addTestSuite('Zend_Gdata_WhereTest');
         $suite->addTestSuite('Zend_Gdata_WhoTest');
 
-        $suite->addTestSuite('Zend_Gdata_Gbase_ItemEntryTest');
-        $suite->addTestSuite('Zend_Gdata_Gbase_ItemFeedTest');        
-        $suite->addTestSuite('Zend_Gdata_Gbase_ItemQueryTest');
-        $suite->addTestSuite('Zend_Gdata_Gbase_SnippetFeedTest');
-        $suite->addTestSuite('Zend_Gdata_Gbase_SnippetQueryTest');        
-        $suite->addTestSuite('Zend_Gdata_Gbase_QueryTest');
-        $suite->addTestSuite('Zend_Gdata_Gbase_BaseAttributeTest');
-
         $suite->addTestSuite('Zend_Gdata_CalendarTest');
         $suite->addTestSuite('Zend_Gdata_CalendarFeedTest');
         $suite->addTestSuite('Zend_Gdata_CalendarEventTest');
         $suite->addTestSuite('Zend_Gdata_CalendarFeedCompositeTest');
         $suite->addTestSuite('Zend_Gdata_Calendar_EventQueryTest');
-        $suite->addTestSuite('Zend_Gdata_Calendar_EventQueryExceptionTest');        
+        $suite->addTestSuite('Zend_Gdata_Calendar_EventQueryExceptionTest');
         $suite->addTestSuite('Zend_Gdata_Calendar_EventEntryTest');
         $suite->addTestSuite('Zend_Gdata_Calendar_AccessLevelTest');
         $suite->addTestSuite('Zend_Gdata_Calendar_ColorTest');
@@ -256,7 +271,7 @@ class Zend_Gdata_AllTests
         $suite->addTestSuite('Zend_Gdata_Calendar_TimezoneTest');
         $suite->addTestSuite('Zend_Gdata_Calendar_WebContentTest');
         $suite->addTestSuite('Zend_Gdata_Calendar_QuickAddTest');
-        
+
         $suite->addTestSuite('Zend_Gdata_Spreadsheets_ColCountTest');
         $suite->addTestSuite('Zend_Gdata_Spreadsheets_RowCountTest');
         $suite->addTestSuite('Zend_Gdata_Spreadsheets_CellTest');
@@ -271,7 +286,7 @@ class Zend_Gdata_AllTests
         $suite->addTestSuite('Zend_Gdata_Spreadsheets_DocumentQueryTest');
         $suite->addTestSuite('Zend_Gdata_Spreadsheets_CellQueryTest');
         $suite->addTestSuite('Zend_Gdata_Spreadsheets_ListQueryTest');
-        
+
         $suite->addTestSuite('Zend_Gdata_Docs_DocumentListFeedTest');
         $suite->addTestSuite('Zend_Gdata_Docs_DocumentListEntryTest');
         $suite->addTestSuite('Zend_Gdata_Docs_QueryTest');
@@ -297,12 +312,22 @@ class Zend_Gdata_AllTests
         $suite->addTestSuite('Zend_Gdata_Gapps_EmailListRecipientQueryTest');
         $suite->addTestSuite('Zend_Gdata_Gapps_EmailListTest');
         $suite->addTestSuite('Zend_Gdata_Gapps_ErrorTest');
+        $suite->addTestSuite('Zend_Gdata_Gapps_GroupEntryTest');
+        $suite->addTestSuite('Zend_Gdata_Gapps_GroupFeedTest');
+        $suite->addTestSuite('Zend_Gdata_Gapps_GroupQueryTest');
         $suite->addTestSuite('Zend_Gdata_Gapps_LoginTest');
+        $suite->addTestSuite('Zend_Gdata_Gapps_MemberEntryTest');
+        $suite->addTestSuite('Zend_Gdata_Gapps_MemberFeedTest');
+        $suite->addTestSuite('Zend_Gdata_Gapps_MemberQueryTest');
         $suite->addTestSuite('Zend_Gdata_Gapps_NameTest');
         $suite->addTestSuite('Zend_Gdata_Gapps_NicknameEntryTest');
         $suite->addTestSuite('Zend_Gdata_Gapps_NicknameFeedTest');
         $suite->addTestSuite('Zend_Gdata_Gapps_NicknameQueryTest');
         $suite->addTestSuite('Zend_Gdata_Gapps_NicknameTest');
+        $suite->addTestSuite('Zend_Gdata_Gapps_OwnerEntryTest');
+        $suite->addTestSuite('Zend_Gdata_Gapps_OwnerFeedTest');
+        $suite->addTestSuite('Zend_Gdata_Gapps_OwnerQueryTest');
+        $suite->addTestSuite('Zend_Gdata_Gapps_PropertyTest');
         $suite->addTestSuite('Zend_Gdata_Gapps_QuotaTest');
         $suite->addTestSuite('Zend_Gdata_Gapps_ServiceExceptionTest');
         $suite->addTestSuite('Zend_Gdata_Gapps_UserEntryTest');
@@ -322,6 +347,13 @@ class Zend_Gdata_AllTests
         $suite->addTestSuite('Zend_Gdata_YouTube_CommentEntryTest');
         $suite->addTestSuite('Zend_Gdata_YouTube_ContactFeedTest');
         $suite->addTestSuite('Zend_Gdata_YouTube_ContactEntryTest');
+        $suite->addTestSuite('Zend_Gdata_YouTube_ActivityEntryTest');
+        $suite->addTestSuite('Zend_Gdata_YouTube_ActivityFeedTest');
+
+        $suite->addTestSuite('Zend_Gdata_Books_CollectionEntryTest');
+        $suite->addTestSuite('Zend_Gdata_Books_CollectionFeedTest');
+        $suite->addTestSuite('Zend_Gdata_Books_VolumeEntryTest');
+        $suite->addTestSuite('Zend_Gdata_Books_VolumeFeedTest');
 
         $skippingOnlineTests = true;
         if (defined('TESTS_ZEND_GDATA_ONLINE_ENABLED') &&
@@ -338,16 +370,11 @@ class Zend_Gdata_AllTests
                 $suite->addTestSuite('Zend_Gdata_GdataOnlineTest');
             }
 
-            if (defined('TESTS_ZEND_GDATA_GBASE_ONLINE_ENABLED') &&
-            constant('TESTS_ZEND_GDATA_GBASE_ONLINE_ENABLED') == true) {
-                $suite->addTestSuite('Zend_Gdata_GbaseOnlineTest');
-            }
-
             if (defined('TESTS_ZEND_GDATA_CALENDAR_ONLINE_ENABLED') &&
             constant('TESTS_ZEND_GDATA_CALENDAR_ONLINE_ENABLED') == true) {
                 $suite->addTestSuite('Zend_Gdata_CalendarOnlineTest');
             }
-            
+
             if (defined('TESTS_ZEND_GDATA_SPREADSHEETS_ONLINE_ENABLED') &&
             constant('TESTS_ZEND_GDATA_SPREADSHEETS_ONLINE_ENABLED') == true) {
                 $suite->addTestSuite('Zend_Gdata_SpreadsheetsOnlineTest');
@@ -362,13 +389,18 @@ class Zend_Gdata_AllTests
             constant('TESTS_ZEND_GDATA_PHOTOS_ONLINE_ENABLED') == true) {
                 $suite->addTestSuite('Zend_Gdata_PhotosOnlineTest');
             }
-        } 
+
+            if (defined('TESTS_ZEND_GDATA_BOOKS_ONLINE_ENABLED') &&
+            constant('TESTS_ZEND_GDATA_BOOKS_ONLINE_ENABLED') == true) {
+                $suite->addTestSuite('Zend_Gdata_BooksOnlineTest');
+            }
+        }
         if (defined('TESTS_ZEND_GDATA_ONLINE_ENABLED') &&
                    constant('TESTS_ZEND_GDATA_ONLINE_ENABLED') == true) {
             /**
              * Tests that do require online access to servers, but
              * don't require the standard authentication credentials
-             */ 
+             */
             $skippingOnlineTests = false;
             if (defined('TESTS_ZEND_GDATA_GAPPS_ONLINE_ENABLED') &&
             constant('TESTS_ZEND_GDATA_GAPPS_ONLINE_ENABLED') == true) {
