@@ -15,13 +15,14 @@
  * @category   Zend
  * @package    Zend_Log
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2007 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: NullTest.php 4384 2007-04-06 12:33:26Z mike $
+ * @version    $Id$
  */
 
-/** PHPUnit_Framework_TestCase */
-require_once 'PHPUnit/Framework/TestCase.php';
+if (!defined('PHPUnit_MAIN_METHOD')) {
+    define('PHPUnit_MAIN_METHOD', 'Zend_Log_Writer_NullTest::main');
+}
 
 /** Zend_Log_Writer_Null */
 require_once 'Zend/Log/Writer/Null.php';
@@ -30,16 +31,36 @@ require_once 'Zend/Log/Writer/Null.php';
  * @category   Zend
  * @package    Zend_Log
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2007 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: NullTest.php 4384 2007-04-06 12:33:26Z mike $
+ * @group      Zend_Log
  */
 class Zend_Log_Writer_NullTest extends PHPUnit_Framework_TestCase
 {
+    public static function main()
+    {
+        $suite  = new PHPUnit_Framework_TestSuite(__CLASS__);
+        $result = PHPUnit_TextUI_TestRunner::run($suite);
+    }
+
     public function testWrite()
     {
         $writer = new Zend_Log_Writer_Null();
         $writer->write(array('message' => 'foo', 'priority' => 42));
     }
 
+    public function testFactory()
+    {
+        $cfg = array('log' => array('memory' => array(
+            'writerName' => "Null"
+        )));
+
+        require_once 'Zend/Log.php';
+        $logger = Zend_Log::factory($cfg['log']);
+        $this->assertTrue($logger instanceof Zend_Log);
+    }
+}
+
+if (PHPUnit_MAIN_METHOD == 'Zend_Log_Writer_NullTest::main') {
+    Zend_Log_Writer_NullTest::main();
 }
